import { ChatMessageDirection } from './ChatMessageDirection';
import { ChatMessageFile } from './ChatMessageFile';
import { ChatMessageStatus } from './ChatMessageStatus';
import { ChatMessageType } from './ChatMessageType';
interface ChatMessageOptions {
    id?: string;
    direction?: ChatMessageDirection;
    type?: ChatMessageType;
    status?: ChatMessageStatus;
    progress?: number;
    timestamp?: number;
}
/**
 * Instances of this class represents a message of the chat.
 * For more information about how instances of this class can be obtained see
 * {@link Chat#getMessages} or {@link Chat#getPendingMessages}.
 */
export declare class ChatMessage {
    private composer;
    private data;
    private id?;
    private direction;
    private type;
    private status;
    private progress;
    private timestamp?;
    /** @ignore */
    static of(composer: string, data: string, { id, direction, type, status, progress, timestamp, }?: ChatMessageOptions): ChatMessage;
    /** @private */
    private constructor();
    /**
     * @ignore
     * Returns a new ChatMessage with the provided values updated.
     * @return {ChatMessage}
     */
    with({ data, id, type, status, progress, timestamp, }?: ChatMessageOptions & {
        data?: ChatMessageFile | string;
    }): ChatMessage;
    /**
     * @desc Returns the ID of the message.
     * @return {string}
     */
    getId(): string | undefined;
    /**
     * @desc Returns the direction of the message.
     * @return {ChatMessageDirection}
     */
    getDirection(): ChatMessageDirection;
    /**
     * @desc Returns the type of the message.
     * @return {ChatMessageType}
     */
    getType(): ChatMessageType;
    /**
    * @desc Returns the address of the composer of the message.
    * @return {string}
    */
    getComposer(): string;
    /**
     * @desc Returns the data of the message.
     * @return {string|ChatMessageFile}
     */
    getData(): ChatMessageFile | string;
    /**
     * @desc Returns the timestamp when the message was sent.
     * @return {number}
     */
    getTimestamp(): number | undefined;
    /**
     * @desc Returns a number between 0 and 100 indicating the percentage of the message
     * that was sent. Note that text messages can only have two values: 0 and 100.
     * @return {number}
     */
    getProgress(): number;
    /**
     * @desc Returns the current status of the message.
     * @return {ChatMessageStatus}
     */
    getStatus(): ChatMessageStatus;
    /**
     * @desc Returns true when the current status of the message is the specified.
     * @param {ChatMessageStatus} status
     * @return {boolean}
     */
    hasStatus(status: ChatMessageStatus): boolean;
}
export {};
